@@ -18,7 +18,7 @@
 /* #undef CARES_HAVE_WS2TCPIP_H */
 /* #undef CARES_HAVE_WINSOCK2_H */
 #define CARES_HAVE_ARPA_NAMESER_H
-#define CARES_HAVE_ARPA_NAMESER_COMPAT_H
+/* #undef CARES_HAVE_ARPA_NAMESER_COMPAT_H */
 
 #ifdef CARES_HAVE_SYS_TYPES_H
 #  include <sys/types.h>
